﻿using System.Collections.Generic;
using HugsLib;
using RimWorld;
using Verse;

namespace PrisonCommons
{
    public class PrisonCommons : ModBase
    {
        public override string ModIdentifier => "me.lubar.PrisonCommons";

        private static readonly HashSet<CompPrisonCommons> comps = new HashSet<CompPrisonCommons>();

        public static bool IsPrisonCommons(Room room)
        {
            if (room.TouchesMapEdge)
            {
                return false; // room must be enclosed
            }

            foreach (var comp in comps)
            {
                if (comp.parent.Spawned && comp.parent.Map == room.Map)
                {
                    if (room == comp.parent.GetRoom())
                    {
                        return true;
                    }
                }
            }

            return false;
        }

        internal static void SetPrisonCommons(CompPrisonCommons comp, bool add)
        {
            if (add)
            {
                comps.Add(comp);
            }
            else
            {
                comps.Remove(comp);
            }
        }

        public static bool IsAllowedDoorway(Pawn p, Room room)
        {
            if (p == null || room == null || !room.IsDoorway)
            {
                return false;
            }

            var prisonerBed = p.ownership.OwnedBed;
            var prisonerBedroom = prisonerBed?.GetRoom();

            int matchingCount = 0;

            foreach (var neighbor in room.Districts[0].Neighbors)
            {
                if (neighbor.Room == prisonerBedroom || PrisonCommons.IsPrisonCommons(neighbor.Room))
                {
                    matchingCount++;
                }
            }

            return matchingCount >= 2;
        }
    }
}
